//
//  LJGLoading.m
//  GenericModules
//
//  Created by mac on 2023/5/23.
//

#import "LJGLoading.h"
#import <Lottie/Lottie.h>
#import <Masonry/Masonry.h>
#import "AppUIDefine.h"

@interface  LJGLoading()

@property (nonatomic, strong) UIView *shadeView; //遮罩视图(防止UI穿透)
@property (nonatomic, strong) LOTAnimationView *loadingAnimation;

@end

@implementation LJGLoading

static LJGLoading *_singleton = nil;

+ (instancetype)sharedManager {
    static dispatch_once_t onceToken;
    dispatch_once(&onceToken, ^{
        _singleton = [[LJGLoading alloc] init];
    });
    return _singleton;
}

- (instancetype)init
{
    self = [super init];
    if (self) {
        [self.shadeView addSubview:self.loadingAnimation];
        [self.loadingAnimation mas_makeConstraints:^(MASConstraintMaker *make) {
            make.center.mas_equalTo(self.shadeView.center);
            make.width.height.equalTo(@(AdaptedWidth(200)));
        }];
    }
    return self;
}

+ (void)show{
    LJGLoading *loading = [LJGLoading sharedManager];
    [xMainWindow addSubview:loading.shadeView];
    [loading.shadeView mas_makeConstraints:^(MASConstraintMaker *make) {
        make.edges.equalTo(xMainWindow);
    }];
    loading.shadeView.hidden = NO;
    [loading.loadingAnimation play];
}

+ (void)showWithView:(UIView *)view{
    LJGLoading *loading = [LJGLoading sharedManager];
    [view addSubview:loading.shadeView];
    [loading.shadeView mas_makeConstraints:^(MASConstraintMaker *make) {
        make.edges.equalTo(view);
    }];
    loading.shadeView.hidden = NO;
    [loading.loadingAnimation play];
}

+ (void)hide{
    LJGLoading *loading = [LJGLoading sharedManager];
    loading.shadeView.hidden = YES;
    [loading.loadingAnimation stop];
}


- (UIView *)shadeView{
    if(nil == _shadeView){
        _shadeView = [[UIView alloc] init];
        _shadeView.hidden = YES;
        _shadeView.backgroundColor = [[UIColor blackColor] colorWithAlphaComponent:0.05];
    }
    return _shadeView;
}

- (LOTAnimationView *)loadingAnimation{
    if(nil == _loadingAnimation){
        _loadingAnimation = [LOTAnimationView animationNamed:@"loadingData.json" inBundle:self.bundle];
        _loadingAnimation.contentMode =UIViewContentModeScaleToFill;
        _loadingAnimation.loopAnimation = YES;//是否循环动画
    }
    return _loadingAnimation;
}

- (NSBundle *)bundle {
    static NSBundle *bundle = nil;
    static dispatch_once_t onceToken;
    dispatch_once(&onceToken, ^{
        bundle = [NSBundle bundleWithPath:[[NSBundle bundleForClass:[self class]] pathForResource:@"GenericModules" ofType:@"bundle"]];
    });
    return bundle;
}


@end
